=========
mtoatools
=========

.. image:: https://img.shields.io/pypi/v/mtoatools.svg
        :target: https://pypi.python.org/pypi/mtoatools

MtoAtools is a set of production tools for use with Arnold for Maya. This package will grow over time.


mtoatools.mattes
================
UI for managing Matte AOVs.

|mattesui|


Table of Contents
=================

.. toctree::
   :maxdepth: 2

   installation
   mattes
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. |mattesui| image:: images/mtoatools_mattes_ui.png
